@@ -49,10 +49,10 @@ from .utils import (
     normalise_svg_path,
 )
 
-__version__ = '0.9.1'
+__version__ = '0.9.2'
 __license__ = 'LGPL 3'
 __author__ = 'Dinu Gherman'
-__date__ = '2019-06-22'
+__date__ = '2019-07-12'
 
 XML_NS = 'http://www.w3.org/XML/1998/namespace'
 
@@ -305,12 +305,12 @@ class Svg2RlgAttributeConverter(AttributeConverter):
     def split_attr_list(attr):
         return shlex.split(attr.strip().replace(',', ' '))
 
-    def convertLength(self, svgAttr, em_base=12, attr_name=None):
+    def convertLength(self, svgAttr, em_base=12, attr_name=None, default=0.0):
         "Convert length to points."
 
         text = svgAttr
         if not text:
-            return 0.0
+            return default
         if ' ' in text.replace(',', ' ').strip():
             logger.debug("Only getting first value of %s" % text)
             text = text.replace(',', ' ').split()[0]
@@ -364,20 +364,13 @@ class Svg2RlgAttributeConverter(AttributeConverter):
     def convertColor(self, svgAttr):
         "Convert string to a RL color object."
 
-        # fix it: most likely all "web colors" are allowed
-        predefined = "aqua black blue fuchsia gray green lime maroon navy "
-        predefined = predefined + "olive orange purple red silver teal white yellow "
-        predefined = predefined + "lawngreen indianred aquamarine lightgreen brown"
-
         # This needs also to lookup values like "url(#SomeName)"...
 
         text = svgAttr
         if not text or text == "none":
             return None
 
-        if text in predefined.split():
-            return self.color_converter(getattr(colors, text))
-        elif text == "currentColor":
+        if text == "currentColor":
             return "currentColor"
         elif len(text) == 7 and text[0] == '#':
             return self.color_converter(colors.HexColor(text))
@@ -393,8 +386,14 @@ class Svg2RlgAttributeConverter(AttributeConverter):
             t = text[3:].replace('%', '').strip('()')
             tup = (float(val)/100.0 for val in t.split(','))
             return self.color_converter(colors.Color(*tup))
-
-        logger.warning("Can't handle color: %s" % text)
+        else:
+            # Test if text is a predefined color constant
+            try:
+                color = getattr(colors, text)
+            except AttributeError:
+                logger.warning("Can't handle color: %s" % text)
+            else:
+                return self.color_converter(color)
 
         return None
 
@@ -571,7 +570,9 @@ class SvgRenderer:
 
         main_group.translate(0 - view_box.x, -view_box.height - view_box.y)
 
-        width, height = self.shape_converter.convert_length_attrs(svg_node, "width", "height")
+        width, height = self.shape_converter.convert_length_attrs(
+            svg_node, "width", "height", defaults=(view_box.width, view_box.height)
+        )
         drawing = Drawing(width, height)
         drawing.add(main_group)
         return drawing
@@ -833,10 +834,12 @@ class SvgRenderer:
             group.scale(1, -1)
         elif view_box:
             x_scale, y_scale = 1, 1
-            width, height = self.shape_converter.convert_length_attrs(node, "width", "height")
-            if view_box.height != height:
+            width, height = self.shape_converter.convert_length_attrs(
+                node, "width", "height", defaults=(None,) * 2
+            )
+            if height is not None and view_box.height != height:
                 y_scale = height / view_box.height
-            if view_box.width != width:
+            if width is not None and view_box.width != width:
                 x_scale = width / view_box.width
             group.scale(x_scale, y_scale * (-1 if outermost else 1))
 
@@ -951,7 +954,11 @@ class Svg2RlgShapeConverter(SvgShapeConverter):
         # Support node both as NodeTracker or lxml node
         getAttr = node.getAttribute if hasattr(node, 'getAttribute') else lambda attr: node.attrib.get(attr, '')
         convLength = self.attrConverter.convertLength
-        return [convLength(getAttr(attr), attr_name=attr, em_base=em_base) for attr in attrs]
+        defaults = kwargs.get('defaults', (0.0,) * len(attrs))
+        return [
+            convLength(getAttr(attr), attr_name=attr, em_base=em_base, default=default)
+            for attr, default in zip(attrs, defaults)
+        ]
 
     def convertLine(self, node):
         x1, y1, x2, y2 = self.convert_length_attrs(node, 'x1', 'y1', 'x2', 'y2')
